:orphan:

Welcome To Dooku
================

.. image:: _static/dooku.png
   :alt: Dooku: a set of libraries for everyday
   :align: center
   :width: 300px

Dooku is a set of libraries for the Python programming language that provides
various useful stuff that you might need in everyday usage. The idea is to
provide a set of libraries and useful functions, just like Boost does in C++
world.

Dooku is a self-contained library and there are no dependencies it requires.
All you need is to install Dooku with pip and enjoy the process of using it.

The documentation is divided into different parts, most of them describe
the libraries that are part of Dooku.

Some links if you interested in the project:

* `Sources on GitHub <https://github.com/ikalnitsky/dooku>`_
* `Report a bug <https://github.com/ikalnitsky/dooku/issues>`_
* `Support me via GitTip <https://www.gittip.com/ikalnitsky/>`_


Table of Content
----------------

.. toctree::
   :maxdepth: 2

   algorithm
   conf
   datetime
   decorator
   ext
